import 'package:flutter/material.dart';
import 'package:flutter_flicker/configuration/configuration.dart';

class DecoratorUtils {
  static String? buildLabelText(String? labelText, {bool? uppercase}) {
    if (labelText == null) {
      return null;
    }

    if (uppercase == null)
      uppercase = FlickerConfiguration.displayOptions.uppercaseLabelAndHint;

    return uppercase ? labelText.toUpperCase() : labelText;
  }

  static String? buildHintText(String? hintText,
      {String? labelText, bool? uppercase, bool readOnly = false}) {
    var text = hintText ?? labelText;
    if (text == null) {
      return null;
    }
    if (readOnly) {
      return ' ';
    }

    if (uppercase == null)
      uppercase = FlickerConfiguration.displayOptions.uppercaseLabelAndHint;

    return uppercase ? text.toUpperCase() : text;
  }

  static String? buildSelectHintText(String? hintText,
      {String? labelText, bool uppercase = true}) {
    final labelBasedHint = _buildLabelBasedHint(labelText);
    return buildHintText(hintText,
        labelText: labelBasedHint, uppercase: uppercase);
  }

  static InputDecoration uppercaseLabelAndHintDecoration(String text,
      {Widget? prefix, Widget? suffix}) {
    return InputDecoration(
      labelText: text.toUpperCase(),
      hintText: text.toUpperCase(),
      prefix: prefix,
      suffix: suffix,
    );
  }

  static String? _buildLabelBasedHint(String? labelText) {
    // todo: fix grammar (a label, an item)
    return labelText == null ? null : 'Select a $labelText';
  }
}
