import 'package:flutter/material.dart';
import 'package:flutter_flicker/configuration/configuration.dart';
import 'decorator_utils.dart';

class FlickerTextInput extends StatelessWidget {
  FlickerTextInput(
      {Key? key,
      this.initialValue,
      this.onChanged,
      this.controller,
      this.labelText,
      this.uppercaseLabelAndHint,
      this.validator,
      this.obscureText = false,
      this.numberOfLines = 1,
      this.width = 250,
      this.readOnly = false,
      this.suffix,
      this.prefix,
      this.onFieldSubmitted})
      : super(key: key);

  final String? initialValue;
  final String? labelText;
  final bool? uppercaseLabelAndHint;
  final ValueChanged<String>? onChanged;
  final Function(String?)? onFieldSubmitted;
  final FormFieldValidator<String>? validator;
  final bool obscureText;
  final int numberOfLines;
  final double width;
  final bool readOnly;
  final Widget? suffix;
  final Widget? prefix;
  final TextEditingController? controller;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: width,
      alignment: Alignment.center,
      child: TextFormField(
        controller: controller,
        initialValue: initialValue,
        obscureText: obscureText,
        readOnly: readOnly,
        enabled: !readOnly,
        obscuringCharacter: '*',
        onChanged: onChanged,
        onFieldSubmitted: onFieldSubmitted,
        style: Theme.of(context).textTheme.subtitle1?.copyWith(
              color: FlickerConfiguration.colors.input,
            ),
        decoration: InputDecoration(
          suffix: suffix,
          prefix: prefix,
          labelText: DecoratorUtils.buildLabelText(
            labelText,
            uppercase: uppercaseLabelAndHint,
          ),
          hintText: DecoratorUtils.buildHintText(
            null,
            labelText: labelText,
            uppercase: uppercaseLabelAndHint,
            readOnly: readOnly,
          ),
          labelStyle:
              Theme.of(context).inputDecorationTheme.labelStyle?.copyWith(
                    color: readOnly
                        ? Colors.grey.shade700
                        : FlickerConfiguration.colors.inputLabel,
                  ),
          hintStyle: Theme.of(context).inputDecorationTheme.hintStyle?.copyWith(
                color: FlickerConfiguration.colors.hintText,
              ),
          enabledBorder: Theme.of(context)
              .inputDecorationTheme
              .enabledBorder
              ?.copyWith(
                borderSide: Theme.of(context)
                    .inputDecorationTheme
                    .enabledBorder
                    ?.borderSide
                    .copyWith(
                      color:
                          FlickerConfiguration.colors.inputControlEnabledBorder,
                    ),
              ),
          focusedBorder: Theme.of(context)
              .inputDecorationTheme
              .focusedBorder
              ?.copyWith(
                borderSide: Theme.of(context)
                    .inputDecorationTheme
                    .focusedBorder
                    ?.borderSide
                    .copyWith(
                      color:
                          FlickerConfiguration.colors.inputControlFocusedBorder,
                    ),
              ),
          disabledBorder:
              Theme.of(context).inputDecorationTheme.disabledBorder?.copyWith(
                    borderSide: Theme.of(context)
                        .inputDecorationTheme
                        .disabledBorder
                        ?.borderSide
                        .copyWith(
                          color: FlickerConfiguration
                              .colors.inputControlDisabledBorder,
                        ),
                  ),
          border: Theme.of(context).inputDecorationTheme.border?.copyWith(
                borderSide: Theme.of(context)
                    .inputDecorationTheme
                    .border
                    ?.borderSide
                    .copyWith(
                      color: FlickerConfiguration.colors.inputControlBorder,
                    ),
              ),
        ),
        validator: validator,
        maxLines: numberOfLines,
      ),
    );
  }
}
