import 'package:flutter_flicker/controls/form_input/decorator_utils.dart';
import 'package:flutter_test/flutter_test.dart';

void  main() {
  group('control decorator utils', () {
    group('labelText', () {
      test('defaults', () {
        expect(DecoratorUtils.buildLabelText('label'), 'LABEL');
        expect(DecoratorUtils.buildLabelText(null), null);
      });

      test('can be uppercase-d', () {
        expect(DecoratorUtils.buildLabelText('label', uppercase: true), 'LABEL');
        expect(DecoratorUtils.buildLabelText('label', uppercase: false), 'label');
      });
    });

    group('hintText', () {
      test('defaults', () {
        expect(DecoratorUtils.buildHintText('hint'), 'HINT');
        expect(DecoratorUtils.buildHintText(null), null);
      });

      test('can be uppercase-d', () {
        expect(DecoratorUtils.buildHintText('hint', uppercase: true), 'HINT');
        expect(DecoratorUtils.buildHintText('hint', uppercase: false), 'hint');
      });

      test('uses label text when hint text not provided', () {
        expect(DecoratorUtils.buildHintText(null, labelText: 'label'), 'LABEL');
        expect(DecoratorUtils.buildHintText(null, labelText: 'label', uppercase: false), 'label');
      });

      test('empty for readOnly', () {
        expect(DecoratorUtils.buildHintText(null, readOnly: true), null);
        expect(DecoratorUtils.buildHintText('hint', readOnly: true), ' ');
        expect(DecoratorUtils.buildHintText(null, labelText: 'label', readOnly: true), ' ');
      });
    });

    group('select hintText', () {
      test('defaults', () {
        expect(DecoratorUtils.buildSelectHintText('hint'), 'HINT');
        expect(DecoratorUtils.buildSelectHintText(null), null, reason: 'no hint and no label: should be null');
      });

      test('fallback to "Select a <labelText>"', () {
        expect(DecoratorUtils.buildSelectHintText(null, labelText: 'label'), 'SELECT A LABEL');
      });

      test('can be uppercase-d', () {
        expect(DecoratorUtils.buildSelectHintText('hint', uppercase: true), 'HINT');
        expect(DecoratorUtils.buildSelectHintText('hint', uppercase: false), 'hint');
        expect(DecoratorUtils.buildSelectHintText(null, labelText: 'thing', uppercase: true), 'SELECT A THING');
      });
    });

    group('uppercaseLabelAndHintDecoration', () {
      test('uses uppercase text for label and hint', () {
        final decoration = DecoratorUtils.uppercaseLabelAndHintDecoration('text');
        expect(decoration.labelText, 'TEXT');
        expect(decoration.hintText, 'TEXT');
      });
    });
  });
}
